---
title: 'antispam:plugin:fromenamespoof'
url: 'https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-fromenamespoof'
markdown: 'https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-fromenamespoof.md'
date: '2026-09-24'
description: 'Perform various tests to detect spoof attempts using the From: header name section. warden --task=antispam:plugin:fromenamespoof Option Value Default Description --fns_extrachars <digit> 50 The closeness when matching the From:addr and From:name. --fns_check <0|1|2> 1 Al…'
taxonomy:
  category:
    - docs
  tag:
    - fromnamespoof
---

[](#)  [ Basics ](https://docs.danami.com/warden/)     [ Command Line Interface ](https://docs.danami.com/warden/command-line-interface)      Antispam       antispam:plugin:fromenamespoof    

# antispam:plugin:fromenamespoof

Perform various tests to detect spoof attempts using the From: header name section.

```
warden --task=antispam:plugin:fromenamespoof
```

| Option | Value | Default | Description |
|---|---|---|---|
| `--fns_extrachars` | <digit> | 50 | The closeness when matching the From:addr and From:name. |
| `--fns_check` | <0\|1\|2> | 1 | Allows you to adjust the level of checking. By default FromNameSpoof will ignore the TLD when testing if From:addr is spoofed. |
| `--fns_ignore_headers` | <string1,string2> |  | Skip emails that have these headers present. |
| `--fns_ignore_headers_add` | <string> |  | Add a single entry to fns\_ignore\_headers. |
| `--fns_ignore_headers_del` | <string> |  | Remove a single entry from fns\_ignore\_headers. |
| `--fns_ignore_dkim` | <string> |  | Skip emails that have been DKIM signed by specific senders. |
| `--fns_ignore_dkim_add` | <string> |  | Add a single entry to fns\_ignore\_dkim. |
| `--fns_ignore_dkim_del` | <string> |  | Remove a single entry from fns\_ignore\_dkim. |
| `--default` | <yes> |  | Reset all settings to their default values. |
| `--default_option` | <option> |  | Reset a specific setting to its default value. |
| `--reload` | <yes> |  | Reload the service after saving settings. |

## Examples

```
// set the fns_extrachars
warden --task=antispam:plugin:fromenamespoof --fns_extrachars='60' --reload=yes

// reset fns_extrachars  to its default value
warden --task=antispam:plugin:fromenamespoof --default_option=fns_extrachars --reload=yes

// reset all settings to their default values
warden --task=antispam:plugin:fromenamespoof --default=yes --reload=yes
```

## Related Pages

- [FromNameSpoof Settings](https://docs.danami.com/warden/settings/antispam/plugin-settings/fromnamespoof "FromNameSpoof Settings")
- [FromNameSpoof](https://docs.danami.com/warden/user-guide/antispam-plugins/fromnamespoof "FromNameSpoof")

 [ ](https://docs.danami.com/warden/user-guide/antispam-plugins/fromnamespoof) [](https://docs.danami.com/warden/settings/antispam/plugin-settings/fromnamespoof)

---

## Navigation

- Previous: [antispam:plugin:freemail](https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-freemail.md)
- Next: [antispam:plugin:neuralnetwork](https://docs.danami.com/warden/command-line-interface/antispam/antispam-plugin-neuralnetwork.md)
